:py:mod:`Heron.docs.conf`
=========================

.. py:module:: Heron.docs.conf


Module Contents
---------------

.. py:data:: project
   :annotation: = Heron

   

.. py:data:: copyright
   :annotation: = 2022, George Dimitriadis

   

.. py:data:: author
   :annotation: = George Dimitriadis

   

.. py:data:: extensions
   :annotation: = []

   

.. py:data:: templates_path
   :annotation: = []

   

.. py:data:: exclude_patterns
   :annotation: = []

   

.. py:data:: html_theme
   :annotation: = sphinx_rtd_theme

   

.. py:data:: html_static_path
   :annotation: = []

   

